@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.005';
+$Time::C::VERSION = '0.006';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -29,7 +29,7 @@ method new ($c: $year = undef, $month = 1, $day = 1, $hour = 0, $minute = 0, $se
 
 method localtime ($c: $epoch, $tz = $ENV{TZ}) {
     $tz = 'UTC' unless defined $tz;
-    $epoch = _to_utc($epoch, $tz);
+    _verify_tz($tz);
     bless {epoch => $epoch, tz => $tz}, $c;
 }
 
@@ -37,37 +37,28 @@ method localtime ($c: $epoch, $tz = $ENV{TZ}) {
 method gmtime ($c: $epoch) { $c->localtime( $epoch, 'UTC' ); }
 
 
-method now ($c: $tz = $ENV{TZ}) { $c->gmtime( time )->tz( $tz // 'UTC' ); }
+method now ($c: $tz = $ENV{TZ}) { $c->localtime( time, $tz ); }
 
 
 method now_utc ($c:) { $c->localtime( time, 'UTC' ); }
 
 
-method from_epoch ($c: $epoch) { $c->localtime( $epoch, 'UTC' ); }
-
-
 method from_string ($c: $str, $format = undef, $expected_tz = 'UTC') {
     my @p = _parse($str, $format, $expected_tz);
 
     bless {epoch => $p[0], tz => $p[1]}, $c;
 }
 
-fun _to_utc ($epoch, $from) {
-    return $epoch if (not defined $from or $from eq 'UTC' or $from eq 'GMT');
-
-    my $offset = eval {
-      Time::Zone::Olson->new({timezone => $from})->local_offset($epoch); };
-
-    croak sprintf "Unknown timezone %s.", $from if not defined $offset;
-
-    return $epoch + $offset * 60;
+fun constrain ($val, $min, $max) {
+    return not ($val > $max or $val < $min);
 }
 
-fun _from_utc ($epoch, $to) {
-    return $epoch if (not defined $to or $to eq 'UTC' or $to eq 'GMT');
-
-    my $offset = Time::Zone::Olson->new({timezone => $to})->local_offset($epoch);
-    return $epoch - $offset * 60;
+fun _verify_tz ($tz) {
+    unless ($tz =~ /^([+-]?\d+):(\d+)$/ and
+      constrain($1, -12, 14) and constrain($2, 0, 60)) {
+        croak sprintf "Unknown timezone: %s", $tz
+          unless eval { Time::Zone::Olson->new({timezone => $tz}); 1; };
+    }
 }
 
 my %tz_offset = (
@@ -135,10 +126,10 @@ fun _parse ($str, $format = undef, $tz = 'UTC') {
 
 
 method epoch ($t: $new_epoch = undef) :lvalue {
-    my $epoch = _from_utc($t->{epoch}, $t->{tz});
+    my $epoch = $t->{epoch};
 
     my $setter = sub {
-        $t->{epoch} = _to_utc($_[0], $t->{tz});
+        $t->{epoch} = $_[0];
         return $t if defined $new_epoch;
         return $_[0];
     };
@@ -151,13 +142,7 @@ method epoch ($t: $new_epoch = undef) :lvalue {
 
 method tz ($t: $new_tz = undef) :lvalue {
     my $setter = sub {
-        unless (
-          $_[0] =~ /^([+-])(\d+):(\d+)$/ and 
-          (($1 eq '+' and $2 < 14 and $3 < 60) or
-          ($1 eq '-' and $2 < 12 and $3 < 60))) {
-            croak sprintf "Unknown timezone: %s", $_[0]
-              unless eval { Time::Zone::Olson->new({timezone => $_[0]}); 1; };
-        }
+        _verify_tz($_[0]);
 
         $t->{tz} = $_[0];
         return $t if defined $new_tz;
@@ -171,6 +156,15 @@ method tz ($t: $new_tz = undef) :lvalue {
 
 
 method offset ($t: $new_offset = undef) :lvalue {
+    my $setter = sub {
+        $t->{tz} = _get_tz($_[0]);
+
+        return $t if defined $new_offset;
+        return $_[0];
+    };
+
+    return $setter->($new_offset) if defined $new_offset;
+
     my $offset = eval { Time::Zone::Olson->new({timezone => $t->{tz}})
       ->local_offset($t->{epoch}); };
 
@@ -182,16 +176,7 @@ method offset ($t: $new_offset = undef) :lvalue {
         }
     }
 
-    my $setter = sub {
-        $t->{tz} = _get_tz($_[0]);
-
-        return $t if defined $new_offset;
-        return $_[0];
-    };
-
-    return $setter->($new_offset) if defined $new_offset;
-
-    croak sprintf "Invalid timezone %s set. Can't find offset.", $t->{tz}
+    croak sprintf "Unknown timezone %s.", $t->{tz}
       if not defined $offset;
 
     sentinel value => $offset, set => $setter;
@@ -485,7 +470,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -600,26 +585,20 @@ This is the time in seconds since the system epoch, usually C<1970-01-01T00:00:0
 
 Creates a Time::C object for the current epoch in the timezone specified in C<$tz> or C<$ENV{TZ}> or C<UTC> if the first two are unspecified.
 
+=over
+
+=item C<$tz>
+
+This is the timezone specification, such as C<Europe/Stockholm> or C<UTC>. If not specified defaults to the timezone specified in C<$ENV{TZ}>, or C<UTC> if that is unspecified.
+
+=back
+
 =head2 now_utc
 
   my $t = Time::C->now_utc();
 
 Creates a Time::C object for the current epoch in C<UTC>.
 
-=head2 from_epoch
-
-  my $t = Time::C->from_epoch($epoch);
-
-Creates a Time::C object for the specified C<$epoch>. The timezone will be C<UTC>.
-
-=over
-
-=item C<$epoch>
-
-This is the time in seconds since the system epoch, usually C<1970-01-01T00:00:00Z>.
-
-=back
-
 =head2 from_string
 
   my $t = Time::C->from_string($str);
